==> smartgwt-12.1p.zip: com/smartgwt/logicalstructure/widgets/menu/MenuLogicalStructure.java <==
package com.smartgwt.logicalstructure.widgets.menu;
import com.smartgwt.client.core.*;
import com.smartgwt.client.rpc.*;
import com.smartgwt.client.i18n.*;
import com.smartgwt.client.event.*;
import com.smartgwt.client.util.*;
import com.smartgwt.client.util.workflow.*;
import com.smartgwt.client.util.workflow.Process; // required to override java.lang.Process
import com.smartgwt.client.types.*;
import com.smartgwt.client.data.*;
import com.smartgwt.client.data.Record;
import com.smartgwt.client.data.fields.*;
import com.smartgwt.client.tools.*;
import com.smartgwt.client.widgets.*;
import com.smartgwt.client.widgets.calendar.*;
import com.smartgwt.client.widgets.chart.*;
import com.smartgwt.client.widgets.cube.*;
import com.smartgwt.client.widgets.drawing.*;
import com.smartgwt.client.widgets.form.*;
import com.smartgwt.client.widgets.form.fields.*;
import com.smartgwt.client.widgets.form.validator.*;
import com.smartgwt.client.widgets.grid.*;
import com.smartgwt.client.widgets.layout.*;
import com.smartgwt.client.widgets.menu.*;
import com.smartgwt.client.widgets.plugins.*;
import com.smartgwt.client.widgets.tab.*;
import com.smartgwt.client.widgets.tableview.*;
import com.smartgwt.client.widgets.tile.*;
import com.smartgwt.client.widgets.toolbar.*;
import com.smartgwt.client.widgets.tree.*;
import com.smartgwt.client.widgets.viewer.*;
import com.smartgwt.logicalstructure.core.*;
import com.smartgwt.logicalstructure.widgets.*;
import com.smartgwt.logicalstructure.widgets.form.*;
import com.smartgwt.logicalstructure.widgets.tile.*;
import com.smartgwt.logicalstructure.widgets.grid.*;
import com.smartgwt.logicalstructure.widgets.chart.*;
import com.smartgwt.logicalstructure.widgets.layout.*;
import com.smartgwt.logicalstructure.widgets.menu.*;
import com.smartgwt.logicalstructure.widgets.tab.*;
import com.smartgwt.logicalstructure.widgets.toolbar.*;
import com.smartgwt.logicalstructure.widgets.tree.*;
import com.smartgwt.logicalstructure.widgets.viewer.*;
import com.smartgwt.logicalstructure.widgets.calendar.*;
import com.smartgwt.logicalstructure.widgets.cube.*;
import com.smartgwt.logicalstructure.widgets.drawing.*;

public class MenuLogicalStructure extends ListGridLogicalStructure {
    public String alternateRecordStyles;
    public String autoDismiss;
    public String autoDismissOnBlur;
    public String autoDraw;
    public String baseStyle;
    public String bodyStyleName;
    public String cancelButtonTitle;
    public String canSelectParentItems;
    public String cascadeAutoDismiss;
    public String cellHeight;
    public DataSource dataSource;
    public String defaultWidth;
    public String editProxyConstructor;
    public String emptyMessage;
    public String fetchSubmenus;
    public String[] fieldsAsStringArrayArray;
    public ListGridField[] fieldsAsListGridFieldArray;
    public String fillSpaceStyleName;
    public String iconBodyStyleName;
    public String iconFillSpaceStyleName;
    public String iconHeight;
    public String iconWidth;
    public Criteria initialCriteria;
    public String menuButtonWidth;
    public String placement;
    public String showAnimationEffect;
    public String showEdges;
    public String showIcons;
    public String showKeys;
    public String showShadow;
    public String showSubmenus;
    public String submenuConstructor;
    public String submenuDirection;
    public Canvas target;
    public String useKeys;
}

==> smartgwt-13.1p.zip: com/smartgwt/logicalstructure/widgets/menu/MenuLogicalStructure.java <==
package com.smartgwt.logicalstructure.widgets.menu;
import com.smartgwt.client.core.*;
import com.smartgwt.client.rpc.*;
import com.smartgwt.client.i18n.*;
import com.smartgwt.client.event.*;
import com.smartgwt.client.util.*;
import com.smartgwt.client.util.workflow.*;
import com.smartgwt.client.util.workflow.Process; // required to override java.lang.Process
import com.smartgwt.client.util.tour.*;
import com.smartgwt.client.types.*;
import com.smartgwt.client.data.*;
import com.smartgwt.client.data.Record;
import com.smartgwt.client.data.fields.*;
import com.smartgwt.client.tools.*;
import com.smartgwt.client.widgets.*;
import com.smartgwt.client.widgets.calendar.*;
import com.smartgwt.client.widgets.chart.*;
import com.smartgwt.client.widgets.cube.*;
import com.smartgwt.client.widgets.drawing.*;
import com.smartgwt.client.widgets.form.*;
import com.smartgwt.client.widgets.form.fields.*;
import com.smartgwt.client.widgets.form.validator.*;
import com.smartgwt.client.widgets.grid.*;
import com.smartgwt.client.widgets.layout.*;
import com.smartgwt.client.widgets.menu.*;
import com.smartgwt.client.widgets.plugins.*;
import com.smartgwt.client.widgets.tab.*;
import com.smartgwt.client.widgets.tableview.*;
import com.smartgwt.client.widgets.tile.*;
import com.smartgwt.client.widgets.toolbar.*;
import com.smartgwt.client.widgets.tree.*;
import com.smartgwt.client.widgets.viewer.*;
import com.smartgwt.logicalstructure.core.*;
import com.smartgwt.logicalstructure.widgets.*;
import com.smartgwt.logicalstructure.widgets.form.*;
import com.smartgwt.logicalstructure.widgets.tile.*;
import com.smartgwt.logicalstructure.widgets.grid.*;
import com.smartgwt.logicalstructure.widgets.chart.*;
import com.smartgwt.logicalstructure.widgets.layout.*;
import com.smartgwt.logicalstructure.widgets.menu.*;
import com.smartgwt.logicalstructure.widgets.tab.*;
import com.smartgwt.logicalstructure.widgets.toolbar.*;
import com.smartgwt.logicalstructure.widgets.tree.*;
import com.smartgwt.logicalstructure.widgets.viewer.*;
import com.smartgwt.logicalstructure.widgets.calendar.*;
import com.smartgwt.logicalstructure.widgets.cube.*;
import com.smartgwt.logicalstructure.widgets.drawing.*;

public class MenuLogicalStructure extends ListGridLogicalStructure {
    public String alternateRecordStyles;
    public String autoDismiss;
    public String autoDismissOnBlur;
    public String autoDraw;
    public String baseStyle;
    public String bodyStyleName;
    public String cancelButtonTitle;
    public String canSaveSearches;
    public String canSelectParentItems;
    public String canShowFilterEditor;
    public String cascadeAutoDismiss;
    public String cellHeight;
    public String checkmarkDisabledImageAsString;
    public ImgHTMLProperties checkmarkDisabledImageAsImgHTMLProperties;
    public String checkmarkImageAsString;
    public ImgHTMLProperties checkmarkImageAsImgHTMLProperties;
    public DataSource dataSource;
    public String defaultWidth;
    public String editProxyConstructor;
    public String emptyMessage;
    public String fetchSubmenus;
    public String[] fieldsAsStringArrayArray;
    public ListGridField[] fieldsAsListGridFieldArray;
    public String fillSpaceStyleName;
    public String filterHiddenItems;
    public String iconBodyStyleName;
    public String iconFillSpaceStyleName;
    public String iconHeight;
    public String iconWidth;
    public Criteria initialCriteria;
    public String itemHiddenProperty;
    public String menuButtonWidth;
    public String placement;
    public String showAnimationEffect;
    public String showEdges;
    public String showIcons;
    public String showKeys;
    public String showShadow;
    public String showSubmenus;
    public String submenuConstructor;
    public String submenuDirection;
    public String submenuDisabledImageAsString;
    public ImgHTMLProperties submenuDisabledImageAsImgHTMLProperties;
    public String submenuImageAsString;
    public ImgHTMLProperties submenuImageAsImgHTMLProperties;
    public Canvas target;
    public String useKeys;
}
